searchData={"items":[{"type":"module","title":"Glot","doc":"Use this module to enable translation features for your module.","ref":"Glot.html"},{"type":"module","title":"Options - Glot","doc":"- `:base` - The base directory for translation files\n- `:sources` - List of translation sources\n- `:default_locale` - The default locale\n- `:watch` - (optional, default: false) Enable live reloading of translations in development","ref":"Glot.html#module-options"},{"type":"module","title":"Glot.Ecto","doc":"Provides the `hint/2` function for translating custom Ecto validation messages\nusing a localized glossary.\n\nDesigned for use in modules that define or consume `Ecto.Changeset` validations.","ref":"Glot.Ecto.html"},{"type":"module","title":"Why? - Glot.Ecto","doc":"Ecto allows adding errors with custom messages and metadata:\n\n    add_error(\n      changeset,\n      :field,\n      \"you're doing it wrong\",\n      foo: \"bar\",\n      validation: :foobar\n    )\n\nLater, you can retrieve that message from the changeset:\n\n    {\"you're doing it wrong\", [foo: \"bar\", validation: :foobar]}\n\n`Glot.Ecto.hint/2` takes this `{message, opts}` tuple along with a `locale`\nand returns a localized, interpolated string — or falls back to the original.","ref":"Glot.Ecto.html#module-why"},{"type":"module","title":"Usage - Glot.Ecto","doc":"defmodule MyApp.Validation do\n      use Glot.Ecto, [\"../locales/validation\"]\n    end\n\n    MyApp.Validation.hint({\"you're doing it wrong\", [foo: \"bar\", validation: :foobar]}, \"en\")\n    #=> \"you're doing bar wrong\"","ref":"Glot.Ecto.html#module-usage"},{"type":"module","title":"Source format - Glot.Ecto","doc":"The glossary is built from JSONL files like this:\n\n    # validation.en.jsonl\n    {\"key\": \"foobar\", \"value\": \"you're doing {{foo}} wrong\"}\n\n    # validation.ru.jsonl\n    {\"key\": \"foobar\", \"value\": \"вы неправильно делаете {{foo}}\"}\n\nFile paths passed to `use Glot.Ecto` should be base paths without extension or locale suffix.","ref":"Glot.Ecto.html#module-source-format"},{"type":"module","title":"Glot.Jsonl","doc":"Jsonlines is simpler than JSON, because each line can be parsed separatelly.\nThis makes it useful for large files, that still need some structure (CSV falls short here).\n\n- https://jsonlines.org/on_the_web/","ref":"Glot.Jsonl.html"},{"type":"function","title":"Glot.Jsonl.list_to_jsonl/1","doc":"","ref":"Glot.Jsonl.html#list_to_jsonl/1"},{"type":"function","title":"Glot.Jsonl.read_from_file/1","doc":"Reads a file with JSON-lines, returning {:ok, rows} or {:error, reason}","ref":"Glot.Jsonl.html#read_from_file/1"},{"type":"function","title":"Glot.Jsonl.read_from_file!/1","doc":"","ref":"Glot.Jsonl.html#read_from_file!/1"},{"type":"function","title":"Glot.Jsonl.write_to_file/2","doc":"Writes JSONLines (https://jsonlines.org/examples/) to a file.","ref":"Glot.Jsonl.html#write_to_file/2"},{"type":"module","title":"Glot.Lexeme","doc":"Internal functions for working with glossary lexemes.\n\nThis module is not part of the public API.\nIt provides utilities to identify, qualify, and resolve localized expressions\nbased on Ecto-style validation metadata.","ref":"Glot.Lexeme.html"},{"type":"function","title":"Glot.Lexeme.identify/1","doc":"Builds a lexeme identifier from Ecto validation options.\n\nThe result is used to construct the glossary key. It attempts to match the most\nspecific form: `validation.key.kind.type`, then `validation.key.kind`, then `validation.key`.\n\nLogs a warning and returns `\"validation.unknown\"` if `:validation` is missing.","ref":"Glot.Lexeme.html#identify/1"},{"type":"function","title":"Examples - Glot.Lexeme.identify/1","doc":"identify(%{validation: :length, kind: :min, type: :string})\n    #=> \"validation.length.min.string\"\n\n    identify(%{validation: :required})\n    #=> \"validation.required\"","ref":"Glot.Lexeme.html#identify/1-examples"},{"type":"function","title":"Glot.Lexeme.lookup/4","doc":"Looks up a localized expression in the glossary by its fully qualified key.\n\nPerforms interpolation of placeholders in the form `{{key}}` using values from `bindings`.\nIf the key is not found, returns `fallback` or the key itself, and logs a warning.","ref":"Glot.Lexeme.html#lookup/4"},{"type":"function","title":"Examples - Glot.Lexeme.lookup/4","doc":"lookup(\"en.validation.required\", glossary, [], nil)\n    #=> \"can't be blank\"\n\n    lookup(\"en.validation.foo\", glossary, [name: \"Alice\"], nil)\n    #=> \"Hello, Alice!\"","ref":"Glot.Lexeme.html#lookup/4-examples"},{"type":"function","title":"Glot.Lexeme.qualify/2","doc":"Prepends a locale prefix to a lexeme to produce a fully qualified glossary key.","ref":"Glot.Lexeme.html#qualify/2"},{"type":"function","title":"Examples - Glot.Lexeme.qualify/2","doc":"qualify(\"validation.required\", \"en\")\n    #=> \"en.validation.required\"","ref":"Glot.Lexeme.html#qualify/2-examples"},{"type":"module","title":"Glot.Lexicon","doc":"Compiles JSONL glossaries into a flat map of localized expressions.\n\nUsed internally by `Glot` to build a lexicon of lexeme–expression mappings.","ref":"Glot.Lexicon.html"},{"type":"function","title":"Glot.Lexicon.compile/2","doc":"Compiles a list of JSONL glossary files into a map of keys (`locale.lexeme`) to expressions.\n\nReturns a tuple of {translations, file_paths} where translations is a map of keys (`locale.lexeme`) to expressions\nand file_paths is a list of file paths that were successfully loaded.","ref":"Glot.Lexicon.html#compile/2"},{"type":"module","title":"Glot.Translator","doc":"","ref":"Glot.Translator.html"},{"type":"function","title":"Glot.Translator.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Glot.Translator.html#child_spec/1"},{"type":"function","title":"Glot.Translator.grep_keys/3","doc":"","ref":"Glot.Translator.html#grep_keys/3"},{"type":"function","title":"Glot.Translator.has_changes?/1","doc":"Checks if there are uncommitted changes.","ref":"Glot.Translator.html#has_changes?/1"},{"type":"function","title":"Glot.Translator.insert_translation/3","doc":"","ref":"Glot.Translator.html#insert_translation/3"},{"type":"function","title":"Glot.Translator.loaded_files/1","doc":"Returns the list of file paths that were used to load translations.","ref":"Glot.Translator.html#loaded_files/1"},{"type":"function","title":"Glot.Translator.reload/1","doc":"Reloads translations from files.","ref":"Glot.Translator.html#reload/1"},{"type":"function","title":"Glot.Translator.start_link/1","doc":"Starts the translator with configuration.","ref":"Glot.Translator.html#start_link/1"},{"type":"function","title":"Glot.Translator.t/5","doc":"","ref":"Glot.Translator.html#t/5"},{"type":"function","title":"Glot.Translator.to_table_name/1","doc":"","ref":"Glot.Translator.html#to_table_name/1"},{"type":"module","title":"Glot.Watcher","doc":"","ref":"Glot.Watcher.html"},{"type":"function","title":"Glot.Watcher.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Glot.Watcher.html#child_spec/1"},{"type":"function","title":"Glot.Watcher.register_module/2","doc":"Registers a module to be notified when files in the given base path change.","ref":"Glot.Watcher.html#register_module/2"},{"type":"function","title":"Glot.Watcher.start_link/1","doc":"Starts the file watcher for live reloading.\nOnly starts in development environment.","ref":"Glot.Watcher.html#start_link/1"},{"type":"function","title":"Glot.Watcher.unregister_module/1","doc":"Unregisters a module from file change notifications.","ref":"Glot.Watcher.html#unregister_module/1"},{"type":"extras","title":"Glot","doc":"# Glot\n\n> A minimalistic translation system for Elixir applications\n\n[![Hex.pm](https://img.shields.io/hexpm/v/glot)](https://hex.pm/packages/glot)\n[![Hex.pm](https://img.shields.io/hexpm/dt/glot)](https://hex.pm/packages/glot)\n[![Build Status](https://img.shields.io/github/actions/workflow/status/maxohq/glot/ci.yml)](https://github.com/maxohq/glot/actions)\n\nGlot provides a simple translation system for Elixir applications using JSONL glossaries. It supports interpolation, live reloading in development, and semantic lexeme-based translations.","ref":"readme.html"},{"type":"extras","title":"Features - Glot","doc":"- **High Performance**: Direct ETS table access for fast lookups\n- **Multi-locale Support**: Easy locale switching with fallback support\n- **Live Reloading**: Automatic translation updates during development\n- **Interpolation**: Dynamic content with `{{variable}}` placeholders\n- **Semantic Keys**: Meaning-based lexemes instead of UI position keys\n- **Module Isolation**: Each module gets its own isolated translation table\n- **Minimal Dependencies**: Only requires `jason` and `file_system`","ref":"readme.html#features"},{"type":"extras","title":"Installation - Glot","doc":"Add `glot` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:glot, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Quick Start - Glot","doc":"","ref":"readme.html#quick-start"},{"type":"extras","title":"1. Create Translation Files - Glot","doc":"Create JSONL files for each locale and domain:\n\n**`priv/translations/game.en.jsonl`:**\n```jsonl\n{\"key\": \"game.won\", \"value\": \"You won!\"}\n{\"key\": \"game.lost\", \"value\": \"Game over.\"}\n{\"key\": \"game.score\", \"value\": \"Your score: {{score}}\"}\n{\"key\": \"game.greeting\", \"value\": \"Hello, {{name}}!\"}\n```\n\n**`priv/translations/game.ru.jsonl`:**\n```jsonl\n{\"key\": \"game.won\", \"value\": \"Вы победили!\"}\n{\"key\": \"game.lost\", \"value\": \"Игра окончена.\"}\n{\"key\": \"game.score\", \"value\": \"Ваш счёт: {{score}}\"}\n{\"key\": \"game.greeting\", \"value\": \"Привет, {{name}}!\"}\n```","ref":"readme.html#1-create-translation-files"},{"type":"extras","title":"2. Use in Your Module - Glot","doc":"```elixir\ndefmodule MyApp.Game do\n  use Glot,\n    base: \"priv/translations\",\n    sources: [\"game\"],\n    default_locale: \"en\",\n    watch: true  # Enable live reloading in development\n\n  def welcome_message(name) do\n    t(\"game.greeting\", name: name)\n  end\n\n  def score_message(score) do\n    t(\"game.score\", score: score)\n  end\n\n  def win_message do\n    t(\"game.won\")\n  end\nend\n```","ref":"readme.html#2-use-in-your-module"},{"type":"extras","title":"3. Use Translations - Glot","doc":"```elixir\n# Basic translation\nMyApp.Game.win_message()\n# => \"You won!\"\n\n# With interpolation\nMyApp.Game.welcome_message(\"Alice\")\n# => \"Hello, Alice!\"\n\n# Different locale\nMyApp.Game.t(\"game.won\", \"ru\")\n# => \"Вы победили!\"\n\n# With interpolation in different locale\nMyApp.Game.t(\"game.score\", \"ru\", score: 100)\n# => \"Ваш счёт: 100\"\n```","ref":"readme.html#3-use-translations"},{"type":"extras","title":"API Reference - Glot","doc":"","ref":"readme.html#api-reference"},{"type":"extras","title":"Configuration Options - Glot","doc":"| Option | Type | Default | Description |\n|--------|------|---------|-------------|\n| `base` | `String` | Required | Base directory for translation files |\n| `sources` | `[String]` | Required | List of translation source names |\n| `default_locale` | `String` | `\"en\"` | Default locale for translations |\n| `watch` | `Boolean` | `false` | Enable live reloading in development |","ref":"readme.html#configuration-options"},{"type":"extras","title":"Functions - Glot","doc":"#### `t(key, locale \\\\ nil, interpolations \\\\ [])`\n\nTranslates a lexeme key to the specified locale with optional interpolation.\n\n```elixir\n# Basic translation\nt(\"game.won\")\n# => \"You won!\"\n\n# With locale\nt(\"game.won\", \"ru\")\n# => \"Вы победили!\"\n\n# With interpolation\nt(\"game.score\", \"en\", score: 42)\n# => \"Your score: 42\"\n\n# With locale and interpolation\nt(\"game.greeting\", \"ru\", name: \"Алиса\")\n# => \"Привет, Алиса!\"\n```\n\n#### `reload()`\n\nReloads translations from files. Useful after manual file changes.\n\n```elixir\nMyApp.Game.reload()\n# => :ok\n```\n\n#### `has_changes?()`\n\nChecks if there are uncommitted changes in the translation table.\n\n```elixir\nMyApp.Game.has_changes?()\n# => false\n```\n\n#### `grep_keys(locale, substring)`\n\nSearches for translation keys containing a substring in a specific locale.\n\n```elixir\nMyApp.Game.grep_keys(\"en\", \"game\")\n# => [{\"en.game.won\", \"You won!\"}, {\"en.game.lost\", \"Game over.\"}]\n```\n\n#### `loaded_files()`\n\nLists loaded files for this module.\n\n```elixir\nMyApp.Game.loaded_files()\n# => [\"\"priv/translations/game.en.jsonl\", \"priv/translations/game.ru.jsonl\"]\n```","ref":"readme.html#functions"},{"type":"extras","title":"Architecture - Glot","doc":"","ref":"readme.html#architecture"},{"type":"extras","title":"Core Components - Glot","doc":"- **`Glot`**: Main module providing the `use Glot` macro\n- **`Glot.Translator`**: GenServer managing translation tables and lookups\n- **`Glot.Lexicon`**: Compiles JSONL files into translation maps\n- **`Glot.Watcher`**: File system watcher for live reloading\n- **`Glot.Jsonl`**: JSONL file parser","ref":"readme.html#core-components"},{"type":"extras","title":"Performance Features - Glot","doc":"- **ETS Tables**: Fast in-memory lookups using Erlang's ETS\n- **Direct Access**: Bypasses GenServer calls for maximum performance\n- **Lazy Loading**: GenServer starts automatically on first use\n- **Module Isolation**: Each module gets its own ETS table","ref":"readme.html#performance-features"},{"type":"extras","title":"Best Practices - Glot","doc":"","ref":"readme.html#best-practices"},{"type":"extras","title":"Semantic Lexemes - Glot","doc":"Use meaningful, semantic keys instead of UI position keys:\n\n```elixir\n# Good - semantic meaning\n{\"key\": \"game.won\", \"value\": \"You won!\"}\n{\"key\": \"user.greeting\", \"value\": \"Hello, {{name}}!\"}\n\n# Bad - UI position\n{\"key\": \"label.bottom_right\", \"value\": \"Submit\"}\n{\"key\": \"button.header\", \"value\": \"Save\"}\n```","ref":"readme.html#semantic-lexemes"},{"type":"extras","title":"File Organization - Glot","doc":"Group translations by domain in separate files:\n\n```\npriv/translations/\n├── game.en.jsonl      # Game-related translations\n├── game.ru.jsonl\n├── user.en.jsonl      # User-related translations\n├── user.ru.jsonl\n├── validation.en.jsonl # Validation messages\n└── validation.ru.jsonl\n```","ref":"readme.html#file-organization"},{"type":"extras","title":"Interpolation - Glot","doc":"Use `{{variable}}` placeholders for dynamic content:\n\n```jsonl\n{\"key\": \"user.welcome\", \"value\": \"Welcome back, {{name}}!\"}\n{\"key\": \"game.score\", \"value\": \"Score: {{score}} points\"}\n{\"key\": \"validation.required\", \"value\": \"{{field}} is required\"}\n```","ref":"readme.html#interpolation"},{"type":"extras","title":"Development - Glot","doc":"","ref":"readme.html#development"},{"type":"extras","title":"Live Reloading - Glot","doc":"Enable live reloading in development by setting `watch: true`:\n\n```elixir\nuse Glot,\n  base: \"priv/translations\",\n  sources: [\"game\"],\n  default_locale: \"en\",\n  watch: true  # Automatically reloads when files change\n```","ref":"readme.html#live-reloading"},{"type":"extras","title":"Testing - Glot","doc":"```elixir\ndefmodule MyApp.GameTest do\n  use ExUnit.Case\n  \n  defmodule TestGame do\n    use Glot,\n      base: \"test/fixtures\",\n      sources: [\"game\"],\n      default_locale: \"en\"\n  end\n\n  test \"translates basic messages\" do\n    assert TestGame.t(\"game.won\") == \"You won!\"\n  end\n\n  test \"handles interpolation\" do\n    assert TestGame.t(\"game.score\", score: 100) == \"Score: 100\"\n  end\nend\n```","ref":"readme.html#testing"},{"type":"extras","title":"License - Glot","doc":"This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.","ref":"readme.html#license"},{"type":"extras","title":"Contributing - Glot","doc":"1. Fork the repository\n2. Create a feature branch (`git checkout -b feature/amazing-feature`)\n3. Commit your changes (`git commit -m 'Add amazing feature'`)\n4. Push to the branch (`git push origin feature/amazing-feature`)\n5. Open a Pull Request","ref":"readme.html#contributing"},{"type":"extras","title":"Performance - Glot","doc":"Glot is designed for efficient translation lookups:\n\n- **Memory efficient**: Uses ETS tables for fast access\n- **Direct table access**: Bypasses GenServer calls for hot paths\n- **Lazy initialization**: GenServer starts only when needed","ref":"readme.html#performance"},{"type":"extras","title":"Related Projects - Glot","doc":"- [Gettext](https://hexdocs.pm/gettext) - Elixir's official internationalization library\n- [ExI18n](https://hex.pm/packages/exi18n) - Alternative i18n solution\n- [Cldr](https://hex.pm/packages/ex_cldr) - Unicode CLDR data for Elixir\n- [glossary](https://hex.pm/packages/glossary/) - Minimalistic semantic translation system for Elixir apps\n\n---\n\n**Made with ❤️ for the Elixir community**","ref":"readme.html#related-projects"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}